Learn R Programming

rlinkedinads (version 0.2.0)

lkd_get_accounts: Get account list

Description

Get account list

Usage

lkd_get_accounts(start = 0, count = 1000)

Value

tibble with account metadata

Arguments

start

Integer, paggination. The index of the first item you want results for.

count

Integer, pagination. The number of items you want included on each page of results. There could be fewer items remaining than the value you specify.