Find Ad Accounts by Authenticated User All ad accounts that an authenticated user has access
lkd_get_accounts_by_authenticated_user(start = 0, count = 1000)tibble with accounts list
Integer, paggination. The index of the first item you want results for.
Integer, pagination. The number of items you want included on each page of results. There could be fewer items remaining than the value you specify.