Find Ad Account Users by Accounts Fetch all users associated with a specific ad account. See next link.
lkd_get_ad_account_users_by_accounts(account_urn_id, start = 0, count = 1000)tibble with users list
accounts ID with a sponsoredAccount URN
Integer, paggination. The index of the first item you want results for.
Integer, pagination. The number of items you want included on each page of results. There could be fewer items remaining than the value you specify.