Learn R Programming

rlinkedinads (version 0.2.0)

lkd_get_campaign_groups: Get Ad campaign Groups Campaign groups provide advertisers a way to manage status, budget, and performance across multiple related campaigns.

Description

Get Ad campaign Groups Campaign groups provide advertisers a way to manage status, budget, and performance across multiple related campaigns.

Usage

lkd_get_campaign_groups(
  account_id = lkd_get_account_id(),
  test = FALSE,
  start = 0,
  count = 1000
)

Value

tibble with campaign groups metadata

Arguments

account_id

your Linkedin Ad Account ID

test

Searches for campaigns based on test or non-test status:

  • True: for test campaigns

  • False: for non-test campaigns If not specified, searches for both test and non-test campaigns.

start

Integer, paggination. The index of the first item you want results for.

count

Integer, pagination. The number of items you want included on each page of results. There could be fewer items remaining than the value you specify.