Get Creatives You can search for creative content in order to get a collection of creatives matching
lkd_get_creatives(account_id = lkd_get_account_id(), start = 0, count = 1000)tibble with creatives metadata
your Linkedin Ad Account ID
Integer, paggination. The index of the first item you want results for.
Integer, pagination. The number of items you want included on each page of results. There could be fewer items remaining than the value you specify.