Get Ad campaign Groups Campaign groups provide advertisers a way to manage status, budget, and performance across multiple related campaigns.
lkd_get_campaign_groups(
account_id = lkd_get_account_id(),
test = FALSE,
start = 0,
count = 1000
)tibble with campaign groups metadata
your Linkedin Ad Account ID
Searches for campaigns based on test or non-test status:
True: for test campaigns
False: for non-test campaigns If not specified, searches for both test and non-test campaigns.
Integer, paggination. The index of the first item you want results for.
Integer, pagination. The number of items you want included on each page of results. There could be fewer items remaining than the value you specify.